@@ -54,6 +54,7 @@ sub new {
     $self = {error => '', items => [], modifiers => [],
 	     costs => [], subtotal => 0, total => 0, 
 	     cache_subtotal => 1, cache_total => 1,
+             created => 0, last_modified => 0,
     };
 
     if ($args{name}) {
@@ -245,7 +246,8 @@ sub add {
     $self->{cache_subtotal} = $self->{cache_total} = 0;
 
     unless ($ret = $self->_combine(\%item)) {
-	push @{$self->{items}}, \%item;
+        push @{$self->{items}}, \%item;
+        $self->{last_modified} = time;
     }
 
     # run hooks after adding item to cart
@@ -295,6 +297,8 @@ sub remove {
 	# removing item from our array
 	splice(@{$self->{items}}, $pos, 1);
 
+    $self->{last_modified} = time;
+
 	$self->_run_hook('after_cart_remove', $self, $item);
 	return 1;
     }
@@ -354,6 +358,8 @@ sub update {
 	    return;
 	}
 
+    $self->{last_modified} = time;
+
 	$self->_run_hook('after_cart_update', $self, $item, $new_item);
 
 	$item->{quantity} = $qty;
@@ -383,6 +389,8 @@ sub clear {
     $self->{cache_subtotal} = 1;
     $self->{cache_total} = 1;
 
+    $self->{last_modified} = time;
+
     return;
 }
 
@@ -429,6 +437,30 @@ sub quantity {
     return $qty;
 }
 
+=head2 created
+
+Returns the time (epoch) when the cart was created.
+
+=cut
+
+sub created {
+    my ($self) = @_;
+
+    return $self->{created};
+}
+
+=head2 last_modified
+
+Returns the time (epoch) when the cart was last modified.
+
+=cut
+
+sub last_modified {
+    my ($self) = @_;
+
+    return $self->{last_modified};
+}
+
 =head2 count
 
 Returns the number of different items in the shopping cart. If you have 5 apples and 6 pears it will return 2 (2 different items).
@@ -568,6 +600,7 @@ sub name {
 	$self->_run_hook('before_cart_rename', $self, $old_name, $_[0]);
 
 	$self->{name} = $_[0];
+    $self->{last_modified} = time;
 
 	$self->_run_hook('after_cart_rename', $self, $old_name, $_[0]);
     }
@@ -609,6 +642,8 @@ sub seed {
     # clear cache flags
     $self->{cache_subtotal} = $self->{cache_total} = 0;
 
+    $self->{last_modified} = time;
+
     return $self->{items};
 }
 
